numMetals = length(N8040_F1);
metalsPerRow = 3; % Number of metals per row
numCols = metalsPerRow * 2; % Each metal has two subplots
numRows = 3; % Calculate number of rows needed

figure; % Create a single figure

for i = 1:numMetals
    % Fit an exponential distribution to the leaching data
    data = [0; N8040_F1(i)];
    expParams = mle(data, 'distribution', 'exponential');
    
    % Simulate leaching concentrations (C_L)
    C_L = exprnd(expParams, numSamples, 1);
    
    % Calculate real leaching concentration (C_L_real) using the corrected formula
    C_L_real = (C_L * intensity * A_real) / V_pond;
    
    % Calculate PEC/PNEC ratio
    PEC_PNEC = C_L_real / PNEC_8040_F1(i);
    
    % Store PEC/PNEC ratios for this metal
    PEC_PNEC_M4F1_case1(:, i) = PEC_PNEC;
    
    % Deterministic approach
    deterministic_C_L_real = (N8040_F1(i) * intensity * A_real) / V_pond;
    deterministic_PEC_PNEC(i) = deterministic_C_L_real / PNEC_8040_F1(i);
    
    % Determine the position of the subplot
    row = ceil(i / metalsPerRow);
    colStart = mod(i-1, metalsPerRow) * 2 + 1;
    
    % Plot the PEC/PNEC ratio as histogram
    subplot(numRows, numCols, (row-1) * numCols + colStart);
    histogram(PEC_PNEC, 50, 'Normalization', 'pdf');
    hold on;
    xline(deterministic_PEC_PNEC(i), 'r', 'LineWidth', 2, 'DisplayName', 'Deterministic');
    xline(mean(PEC_PNEC), 'b', 'LineWidth', 2, 'DisplayName', 'Monte Carlo Mean');
    hold off;
    title(['PEC/PNEC for ', metals_M4_f1{i}]);
    xlabel('PEC/PNEC');
    ylabel('PDF');
    legend('show', 'Location', 'best');
end
